Learn R Programming

markstat (version 0.1.5)

lmcorrinhom.ppp: Local mark correlation functions for inhomogeneous point patterns on Euclidean spaces.

Description

Local mark correlation functions for inhomogeneous point patterns on Euclidean spaces.

Usage

# S3 method for ppp
lmcorrinhom(X,
ftype = c("variogram", "stoyan", "rcorr", "shimatani",
 "beisbart", "isham", "stoyancov", "schlather"),
r = NULL,
lambda = NULL,
method_lambda = c("kernel", "Voronoi"),
bw = bw.scott,
f = NULL,
method = c("density", "loess"),
correction = c("Ripley", "translate", "none"),
normalise = TRUE,
tol = 0.01,
...)

Value

A data.frame where the first column contains the values of the argument \(r\) at which the mark correlation function is evaluated, and the remaining columns contain the estimated values of the mark correlation function for each data point; column names correspond to the IDs of the data points. If there are multiple numeric marks, the result will instead be a list, with each element corresponding to one of the marks.

Arguments

X

An object of class ppp.

ftype

Type of the test function \(t_f\). Currently any selection of "variogram", "stoyan", "rcorr", "shimatani", "beisbart", "isham", "stoyancov", "schlather".

r

Optional. The values of the argument r at which the mark correlation function should be evaluated.

lambda

Estimated intensity at data points. If not given, it will be estimated internally. See details.

method_lambda

The method to be used for estimating intensity at data points, if lambda = NULL.

bw

Bandwidth method to be used for estimating intensity at data points if lambda = NULL and method_lambda = "kernel".

f

Optional. Test function \(t_f\) used in the definition of the mark correlation function. If ftype is given, \(t_f\) should be NULL.

method

Type of smoothing, either density or loess.

correction

Type of edge correction to be applied, either of "Ripley", "translate", "none".

normalise

If normalise=FALSE, only the numerator of the expression for the mark correlation function will be computed.

tol

Tolerance used in the calculation of the conditional mean of marks. This is used only if ftype is schlather.

...

Arguments passed to unnormdensity or loess.

Author

Mehdi Moradi m2.moradi@yahoo.com and Matthias Eckardt

Details

This function computes local mark correlation functions for an inhomogeneous point pattern in \(\mathbb{R}^2\). See the details of test functions used in mcorrinhom.ppp. Technical details are given in Eckardt and Moradi (2025) and Moradi and Eckardt (2025).

References

Moradi, M., & Eckardt, M. (2025). Inhomogeneous mark correlation functions for general marked point processes. arXiv e-prints, arXiv-2505.

Eckardt, M., & Moradi, M. (2025). Local indicators of mark association for marked spatial point processes.

See Also

mcorrinhom.ppp.

Examples

Run this code
 library(spatstat.geom)
 library(spatstat.random)
 library(spatstat.explore)
 X <- rpoispp(function(x,y) {100 * exp(-3*x)}, 100)
 marks(X) <- runif(npoints(X), 1, 10)
 mcorrinhom.ppp(X, ftype = "stoyan",
                method = "density", correction = "translate",
                method_lambda = "kernel", bw = bw.scott)

Run the code above in your browser using DataLab